@@ -1,6 +1,7 @@
 package aws
 
 import (
+	"github.com/sirupsen/logrus"
 	"github.com/snyk/driftctl/pkg/remote/aws/repository"
 	remoteerror "github.com/snyk/driftctl/pkg/remote/error"
 	"github.com/snyk/driftctl/pkg/resource"
@@ -32,6 +33,10 @@ func (e *EC2EipEnumerator) Enumerate() ([]*resource.Resource, error) {
 	results := make([]*resource.Resource, 0, len(addresses))
 
 	for _, address := range addresses {
+		if address.AllocationId == nil {
+			logrus.Warn("Elastic IP does not have an allocation ID, ignoring")
+			continue
+		}
 		results = append(
 			results,
 			e.factory.CreateAbstractResource(
